@@ -19,17 +19,13 @@
 package org.apache.myfaces.spi.impl;
 
 import org.apache.myfaces.config.DefaultFacesConfigResourceProvider;
-import org.apache.myfaces.shared.util.ClassUtils;
+import org.apache.myfaces.util.lang.ClassUtils;
 import org.apache.myfaces.spi.FacesConfigResourceProvider;
 import org.apache.myfaces.spi.FacesConfigResourceProviderFactory;
 import org.apache.myfaces.spi.ServiceProviderFinderFactory;
 
-import jakarta.faces.FacesException;
 import jakarta.faces.context.ExternalContext;
 import java.lang.reflect.InvocationTargetException;
-import java.security.AccessController;
-import java.security.PrivilegedActionException;
-import java.security.PrivilegedExceptionAction;
 import java.util.List;
 import java.util.logging.Level;
 import java.util.logging.Logger;
@@ -51,58 +47,24 @@ public class DefaultFacesConfigResourceProviderFactory extends FacesConfigResour
     }    
     
     @Override
-    public FacesConfigResourceProvider createFacesConfigResourceProvider(
-            ExternalContext externalContext)
+    public FacesConfigResourceProvider createFacesConfigResourceProvider(ExternalContext externalContext)
     {
-        FacesConfigResourceProvider returnValue = null;
-        final ExternalContext extContext = externalContext;
+        FacesConfigResourceProvider instance = null;
+
         try
         {
-            if (System.getSecurityManager() != null)
-            {
-                returnValue = AccessController.doPrivileged(new PrivilegedExceptionAction<FacesConfigResourceProvider>()
-                        {
-                            public FacesConfigResourceProvider run() throws ClassNotFoundException,
-                                    NoClassDefFoundError,
-                                    InstantiationException,
-                                    IllegalAccessException,
-                                    InvocationTargetException,
-                                    PrivilegedActionException
-                            {
-                                return resolveFacesConfigResourceProviderFromService(extContext);
-                            }
-                        });
-            }
-            else
-            {
-                returnValue = resolveFacesConfigResourceProviderFromService(extContext);
-            }
+            instance = resolveFacesConfigResourceProviderFromService(externalContext);
         }
-        catch (ClassNotFoundException e)
+        catch (ClassNotFoundException | NoClassDefFoundError e)
         {
             // ignore
         }
-        catch (NoClassDefFoundError e)
-        {
-            // ignore
-        }
-        catch (InstantiationException e)
+        catch (InstantiationException | IllegalAccessException | InvocationTargetException e)
         {
             getLogger().log(Level.SEVERE, "", e);
         }
-        catch (IllegalAccessException e)
-        {
-            getLogger().log(Level.SEVERE, "", e);
-        }
-        catch (InvocationTargetException e)
-        {
-            getLogger().log(Level.SEVERE, "", e);
-        }
-        catch (PrivilegedActionException e)
-        {
-            throw new FacesException(e);
-        }
-        return returnValue;
+
+        return instance;
     }
     
     private FacesConfigResourceProvider resolveFacesConfigResourceProviderFromService(
@@ -110,8 +72,7 @@ public class DefaultFacesConfigResourceProviderFactory extends FacesConfigResour
             NoClassDefFoundError,
             InstantiationException,
             IllegalAccessException,
-            InvocationTargetException,
-            PrivilegedActionException
+            InvocationTargetException
     {
         List<String> classList = (List<String>) externalContext.getApplicationMap().get(FACES_CONFIG_PROVIDER_LIST);
         if (classList == null)
