@@ -18,16 +18,17 @@
  */
 package org.apache.myfaces.application.flow;
 
-import javax.enterprise.context.ContextNotActiveException;
-import javax.faces.application.ConfigurableNavigationHandler;
-import javax.faces.application.NavigationCase;
-import javax.faces.application.StateManager;
-import javax.faces.component.UICommand;
-import javax.faces.flow.Flow;
-import org.apache.myfaces.mc.test.core.AbstractMyFacesCDIRequestTestCase;
-import org.apache.myfaces.shared.config.MyfacesConfig;
-import org.junit.Assert;
-import org.junit.Test;
+import jakarta.enterprise.context.ContextNotActiveException;
+import jakarta.faces.application.ConfigurableNavigationHandler;
+import jakarta.faces.application.NavigationCase;
+import jakarta.faces.application.StateManager;
+import jakarta.faces.component.UICommand;
+import jakarta.faces.flow.Flow;
+
+import org.apache.myfaces.config.webparameters.MyfacesConfig;
+import org.apache.myfaces.test.core.AbstractMyFacesCDIRequestTestCase;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 
 /**
  * This test is the same as FlowMyFacesRequestTestCase with the diference that
@@ -48,10 +49,10 @@ public class FlowMyFacesCDIRequestTestCase extends AbstractMyFacesCDIRequestTest
         super.setUpWebConfigParams();
         servletContext.addInitParameter("org.apache.myfaces.annotation.SCAN_PACKAGES","org.apache.myfaces.application.flow");
         servletContext.addInitParameter(StateManager.STATE_SAVING_METHOD_PARAM_NAME, StateManager.STATE_SAVING_METHOD_CLIENT);
-        servletContext.addInitParameter("javax.faces.PARTIAL_STATE_SAVING", "true");
-        servletContext.addInitParameter(MyfacesConfig.INIT_PARAM_REFRESH_TRANSIENT_BUILD_ON_PSS, "auto");
-        servletContext.addInitParameter("javax.faces.CONFIG_FILES", "/WEB-INF/flow1-flow.xml");
-        servletContext.addInitParameter("javax.faces.CLIENT_WINDOW_MODE", "url");
+        servletContext.addInitParameter("jakarta.faces.PARTIAL_STATE_SAVING", "true");
+        servletContext.addInitParameter(MyfacesConfig.REFRESH_TRANSIENT_BUILD_ON_PSS, "auto");
+        servletContext.addInitParameter("jakarta.faces.CONFIG_FILES", "/WEB-INF/flow1-flow.xml");
+        servletContext.addInitParameter("jakarta.faces.CLIENT_WINDOW_MODE", "url");
     }
     
     @Test
@@ -64,14 +65,14 @@ public class FlowMyFacesCDIRequestTestCase extends AbstractMyFacesCDIRequestTest
         
         NavigationCase navCase = handler.getNavigationCase(facesContext, null, "flow1");
         
-        Assert.assertNotNull(navCase);
+        Assertions.assertNotNull(navCase);
         
         NavigationCase contentCase = handler.getNavigationCase(facesContext, null, "flow1_content");
         
-        Assert.assertNull(contentCase);
+        Assertions.assertNull(contentCase);
         
         // Check begin view node
-        Assert.assertEquals("/flow1/begin.xhtml", navCase.getToViewId(facesContext));
+        Assertions.assertEquals("/flow1/begin.xhtml", navCase.getToViewId(facesContext));
         
         renderResponse();
        
@@ -82,17 +83,17 @@ public class FlowMyFacesCDIRequestTestCase extends AbstractMyFacesCDIRequestTest
         processLifecycleExecute();
         
         Flow currentFlow = facesContext.getApplication().getFlowHandler().getCurrentFlow(facesContext);
-        Assert.assertNotNull(currentFlow);
+        Assertions.assertNotNull(currentFlow);
         
         // Check Flow1Bean can be created
         Flow1Bean bean1 = facesContext.getApplication().evaluateExpressionGet(
             facesContext, "#{flow1Bean}", Flow1Bean.class);
-        Assert.assertNotNull(bean1);
-        Assert.assertEquals(bean1.getPostConstructCalled(), "true");
+        Assertions.assertNotNull(bean1);
+        Assertions.assertEquals(bean1.getPostConstructCalled(), "true");
         
         contentCase = handler.getNavigationCase(facesContext, null, "flow1_content");
         
-        Assert.assertNotNull(contentCase);
+        Assertions.assertNotNull(contentCase);
     }
     
     @Test
@@ -105,14 +106,14 @@ public class FlowMyFacesCDIRequestTestCase extends AbstractMyFacesCDIRequestTest
         
         NavigationCase navCase = handler.getNavigationCase(facesContext, null, "flow1");
         
-        Assert.assertNotNull(navCase);
+        Assertions.assertNotNull(navCase);
         
         NavigationCase contentCase = handler.getNavigationCase(facesContext, null, "flow1_content");
         
-        Assert.assertNull(contentCase);
+        Assertions.assertNull(contentCase);
         
         // Check begin view node
-        Assert.assertEquals("/flow1/begin.xhtml", navCase.getToViewId(facesContext));
+        Assertions.assertEquals("/flow1/begin.xhtml", navCase.getToViewId(facesContext));
         
         renderResponse();
        
@@ -123,16 +124,16 @@ public class FlowMyFacesCDIRequestTestCase extends AbstractMyFacesCDIRequestTest
         processLifecycleExecute();
         
         Flow currentFlow = facesContext.getApplication().getFlowHandler().getCurrentFlow(facesContext);
-        Assert.assertNotNull(currentFlow);
-        Assert.assertEquals("flow1", currentFlow.getId());
+        Assertions.assertNotNull(currentFlow);
+        Assertions.assertEquals("flow1", currentFlow.getId());
         
         facesContext.getApplication().getFlowHandler().getCurrentFlowScope().put("flow1","value1");
         
         // Check the bean with @FlowScoped annotation can be instantiated
         Flow1Bean bean1 = facesContext.getApplication().evaluateExpressionGet(
             facesContext, "#{flow1Bean}", Flow1Bean.class);
-        Assert.assertNotNull(bean1);
-        Assert.assertEquals(bean1.getPostConstructCalled(), "true");        
+        Assertions.assertNotNull(bean1);
+        Assertions.assertEquals(bean1.getPostConstructCalled(), "true");        
         bean1.setName("John");
         
         renderResponse();
@@ -143,30 +144,30 @@ public class FlowMyFacesCDIRequestTestCase extends AbstractMyFacesCDIRequestTest
         processLifecycleExecute();
         
         currentFlow = facesContext.getApplication().getFlowHandler().getCurrentFlow(facesContext);
-        Assert.assertNotNull(currentFlow);
-        Assert.assertEquals("flow2", currentFlow.getId());
-        Assert.assertFalse(facesContext.getApplication().getFlowHandler().getCurrentFlowScope().containsKey("flow1"));
+        Assertions.assertNotNull(currentFlow);
+        Assertions.assertEquals("flow2", currentFlow.getId());
+        Assertions.assertFalse(facesContext.getApplication().getFlowHandler().getCurrentFlowScope().containsKey("flow1"));
         facesContext.getApplication().getFlowHandler().getCurrentFlowScope().put("flow2","value2");
         
         Flow2Bean bean2 = facesContext.getApplication().evaluateExpressionGet(
             facesContext, "#{flow2Bean}", Flow2Bean.class);
-        Assert.assertNotNull(bean2);
-        Assert.assertEquals(bean2.getPostConstructCalled(), "true");
+        Assertions.assertNotNull(bean2);
+        Assertions.assertEquals(bean2.getPostConstructCalled(), "true");
         
         Flow1Bean bean1_1 = facesContext.getApplication().evaluateExpressionGet(
             facesContext, "#{flow1Bean}", Flow1Bean.class);
-        Assert.assertEquals(bean1_1.getName(), "John");
+        Assertions.assertEquals(bean1_1.getName(), "John");
         
         Flow21Bean bean2_1 = facesContext.getApplication().evaluateExpressionGet(
             facesContext, "#{flow21Bean}", Flow21Bean.class);
-        Assert.assertNotNull(bean2_1);
-        Assert.assertEquals(bean2_1.getPostConstructCalled(), "true");
-        Assert.assertNotNull(bean2_1.getFlow1Bean());
+        Assertions.assertNotNull(bean2_1);
+        Assertions.assertEquals(bean2_1.getPostConstructCalled(), "true");
+        Assertions.assertNotNull(bean2_1.getFlow1Bean());
 
         renderResponse();
         
         //Check current view is the begin of flow2
-        Assert.assertEquals("/flow2/begin.xhtml", facesContext.getViewRoot().getViewId());
+        Assertions.assertEquals("/flow2/begin.xhtml", facesContext.getViewRoot().getViewId());
         
         UICommand button3 = (UICommand) facesContext.getViewRoot().findComponent("mainForm:content");
         client.submit(button3);
@@ -174,11 +175,11 @@ public class FlowMyFacesCDIRequestTestCase extends AbstractMyFacesCDIRequestTest
         renderResponse();
         
         currentFlow = facesContext.getApplication().getFlowHandler().getCurrentFlow(facesContext);
-        Assert.assertNotNull(currentFlow);
-        Assert.assertEquals("flow2", currentFlow.getId());
+        Assertions.assertNotNull(currentFlow);
+        Assertions.assertEquals("flow2", currentFlow.getId());
 
         NavigationCase endCase = handler.getNavigationCase(facesContext, null, "end");
-        Assert.assertNotNull(endCase);
+        Assertions.assertNotNull(endCase);
         
         UICommand button4 = (UICommand) facesContext.getViewRoot().findComponent("mainForm:end_flow");
         client.submit(button4);
@@ -189,15 +190,15 @@ public class FlowMyFacesCDIRequestTestCase extends AbstractMyFacesCDIRequestTest
         // to chain all commands. The difficulty here resides in the context should be resolved properly, and
         // there are a couple of recursive calls that needs to be solved.
         currentFlow = facesContext.getApplication().getFlowHandler().getCurrentFlow(facesContext);
-        Assert.assertNull(currentFlow);
-        Assert.assertEquals("/flow1_end.xhtml", facesContext.getViewRoot().getViewId());
+        Assertions.assertNull(currentFlow);
+        Assertions.assertEquals("/flow1_end.xhtml", facesContext.getViewRoot().getViewId());
         
         try
         {
             Flow1Bean bean1_2 = facesContext.getApplication().evaluateExpressionGet(
                 facesContext, "#{flow1Bean}", Flow1Bean.class);
             bean1_2.getName();
-            Assert.fail("Invocation show throw NullPointerException or ContextNotActiveException");
+            Assertions.fail("Invocation show throw NullPointerException or ContextNotActiveException");
         }
         catch (ContextNotActiveException e)
         {
@@ -228,23 +229,23 @@ public class FlowMyFacesCDIRequestTestCase extends AbstractMyFacesCDIRequestTest
         
         processLifecycleExecute();
         
-        Assert.assertEquals("/flow4/flow4.xhtml", facesContext.getViewRoot().getViewId());
+        Assertions.assertEquals("/flow4/flow4.xhtml", facesContext.getViewRoot().getViewId());
         
         Flow currentFlow = facesContext.getApplication().getFlowHandler().getCurrentFlow(facesContext);
-        Assert.assertNotNull(currentFlow);
-        Assert.assertEquals(currentFlow.getId(), "flow4");
+        Assertions.assertNotNull(currentFlow);
+        Assertions.assertEquals(currentFlow.getId(), "flow4");
         
         renderResponse();
         
         NavigationCase goFlowBase = handler.getNavigationCase(facesContext, null, "call_flow5_4");
-        Assert.assertNotNull(goFlowBase);
+        Assertions.assertNotNull(goFlowBase);
         
         UICommand button2 = (UICommand) facesContext.getViewRoot().findComponent("mainForm:call_flow5");
         client.submit(button2);
         
         processLifecycleExecute();
         
-        Assert.assertEquals("/flow5/flow5.xhtml", facesContext.getViewRoot().getViewId());
+        Assertions.assertEquals("/flow5/flow5.xhtml", facesContext.getViewRoot().getViewId());
 
         renderResponse();
     }
@@ -277,11 +278,11 @@ public class FlowMyFacesCDIRequestTestCase extends AbstractMyFacesCDIRequestTest
         processLifecycleExecute();
         
         facesContext.getApplication().getFlowHandler().getCurrentFlowScope().put("flowA","valueA_1");
-        Assert.assertEquals("/flowA/flowA.xhtml", facesContext.getViewRoot().getViewId());
+        Assertions.assertEquals("/flowA/flowA.xhtml", facesContext.getViewRoot().getViewId());
         
         Flow currentFlow = facesContext.getApplication().getFlowHandler().getCurrentFlow(facesContext);
-        Assert.assertNotNull(currentFlow);
-        Assert.assertEquals(currentFlow.getId(), "flowA");
+        Assertions.assertNotNull(currentFlow);
+        Assertions.assertEquals(currentFlow.getId(), "flowA");
         
         renderResponse();
         
@@ -291,15 +292,15 @@ public class FlowMyFacesCDIRequestTestCase extends AbstractMyFacesCDIRequestTest
         processLifecycleExecute();
         
         currentFlow = facesContext.getApplication().getFlowHandler().getCurrentFlow(facesContext);
-        Assert.assertNotNull(currentFlow);
-        Assert.assertEquals("flowB", currentFlow.getId());
-        Assert.assertFalse(facesContext.getApplication().getFlowHandler().getCurrentFlowScope().containsKey("flowA"));
+        Assertions.assertNotNull(currentFlow);
+        Assertions.assertEquals("flowB", currentFlow.getId());
+        Assertions.assertFalse(facesContext.getApplication().getFlowHandler().getCurrentFlowScope().containsKey("flowA"));
         facesContext.getApplication().getFlowHandler().getCurrentFlowScope().put("flowB","valueB_1");
         
         renderResponse();
         
         //Check current view is the begin of flow2
-        Assert.assertEquals("/flowB/flowB.xhtml", facesContext.getViewRoot().getViewId());
+        Assertions.assertEquals("/flowB/flowB.xhtml", facesContext.getViewRoot().getViewId());
         
         UICommand button3 = (UICommand) facesContext.getViewRoot().findComponent("mainForm:call_flow_A");
         client.submit(button3);
@@ -307,15 +308,15 @@ public class FlowMyFacesCDIRequestTestCase extends AbstractMyFacesCDIRequestTest
         processLifecycleExecute();
         
         currentFlow = facesContext.getApplication().getFlowHandler().getCurrentFlow(facesContext);
-        Assert.assertNotNull(currentFlow);
-        Assert.assertEquals("flowA", currentFlow.getId());
-        Assert.assertFalse(facesContext.getApplication().getFlowHandler().getCurrentFlowScope().containsKey("flowB"));
+        Assertions.assertNotNull(currentFlow);
+        Assertions.assertEquals("flowA", currentFlow.getId());
+        Assertions.assertFalse(facesContext.getApplication().getFlowHandler().getCurrentFlowScope().containsKey("flowB"));
         facesContext.getApplication().getFlowHandler().getCurrentFlowScope().put("flowA","valueA_2");
         
         renderResponse();
         
         //Check current view is the begin of flow2
-        Assert.assertEquals("/flowA/flowA.xhtml", facesContext.getViewRoot().getViewId());
+        Assertions.assertEquals("/flowA/flowA.xhtml", facesContext.getViewRoot().getViewId());
         
         UICommand button4 = (UICommand) facesContext.getViewRoot().findComponent("mainForm:call_flow_B");
         client.submit(button4);
@@ -323,15 +324,15 @@ public class FlowMyFacesCDIRequestTestCase extends AbstractMyFacesCDIRequestTest
         processLifecycleExecute();
         
         currentFlow = facesContext.getApplication().getFlowHandler().getCurrentFlow(facesContext);
-        Assert.assertNotNull(currentFlow);
-        Assert.assertEquals("flowB", currentFlow.getId());
-        Assert.assertFalse(facesContext.getApplication().getFlowHandler().getCurrentFlowScope().containsKey("flowA"));
+        Assertions.assertNotNull(currentFlow);
+        Assertions.assertEquals("flowB", currentFlow.getId());
+        Assertions.assertFalse(facesContext.getApplication().getFlowHandler().getCurrentFlowScope().containsKey("flowA"));
         facesContext.getApplication().getFlowHandler().getCurrentFlowScope().put("flowB","valueB_2");
         
         renderResponse();
         
         //Check current view is the begin of flow2
-        Assert.assertEquals("/flowB/flowB.xhtml", facesContext.getViewRoot().getViewId());
+        Assertions.assertEquals("/flowB/flowB.xhtml", facesContext.getViewRoot().getViewId());
         
         UICommand button5 = (UICommand) facesContext.getViewRoot().findComponent("mainForm:end_flow");
         client.submit(button5);
@@ -339,9 +340,9 @@ public class FlowMyFacesCDIRequestTestCase extends AbstractMyFacesCDIRequestTest
         processLifecycleExecute();
         
         currentFlow = facesContext.getApplication().getFlowHandler().getCurrentFlow(facesContext);
-        Assert.assertNotNull(currentFlow);
-        Assert.assertEquals("flowA", currentFlow.getId());
-        Assert.assertEquals("valueA_2", facesContext.getApplication().getFlowHandler().getCurrentFlowScope().get("flowA"));
+        Assertions.assertNotNull(currentFlow);
+        Assertions.assertEquals("flowA", currentFlow.getId());
+        Assertions.assertEquals("valueA_2", facesContext.getApplication().getFlowHandler().getCurrentFlowScope().get("flowA"));
         
         renderResponse();
         
@@ -351,9 +352,9 @@ public class FlowMyFacesCDIRequestTestCase extends AbstractMyFacesCDIRequestTest
         processLifecycleExecute();
         
         currentFlow = facesContext.getApplication().getFlowHandler().getCurrentFlow(facesContext);
-        Assert.assertNotNull(currentFlow);
-        Assert.assertEquals("flowB", currentFlow.getId());
-        Assert.assertEquals("valueB_1", facesContext.getApplication().getFlowHandler().getCurrentFlowScope().get("flowB"));
+        Assertions.assertNotNull(currentFlow);
+        Assertions.assertEquals("flowB", currentFlow.getId());
+        Assertions.assertEquals("valueB_1", facesContext.getApplication().getFlowHandler().getCurrentFlowScope().get("flowB"));
 
         renderResponse();
         
@@ -363,9 +364,9 @@ public class FlowMyFacesCDIRequestTestCase extends AbstractMyFacesCDIRequestTest
         processLifecycleExecute();
         
         currentFlow = facesContext.getApplication().getFlowHandler().getCurrentFlow(facesContext);
-        Assert.assertNotNull(currentFlow);
-        Assert.assertEquals("flowA", currentFlow.getId());
-        Assert.assertEquals("valueA_1", facesContext.getApplication().getFlowHandler().getCurrentFlowScope().get("flowA"));
+        Assertions.assertNotNull(currentFlow);
+        Assertions.assertEquals("flowA", currentFlow.getId());
+        Assertions.assertEquals("valueA_1", facesContext.getApplication().getFlowHandler().getCurrentFlowScope().get("flowA"));
         
         renderResponse();
     }
@@ -387,11 +388,11 @@ public class FlowMyFacesCDIRequestTestCase extends AbstractMyFacesCDIRequestTest
         processLifecycleExecute();
         
         facesContext.getApplication().getFlowHandler().getCurrentFlowScope().put("flowA","valueA_1");
-        Assert.assertEquals("/flowA/flowA.xhtml", facesContext.getViewRoot().getViewId());
+        Assertions.assertEquals("/flowA/flowA.xhtml", facesContext.getViewRoot().getViewId());
         
         Flow currentFlow = facesContext.getApplication().getFlowHandler().getCurrentFlow(facesContext);
-        Assert.assertNotNull(currentFlow);
-        Assert.assertEquals(currentFlow.getId(), "flowA");
+        Assertions.assertNotNull(currentFlow);
+        Assertions.assertEquals(currentFlow.getId(), "flowA");
         
         renderResponse();
         
@@ -402,9 +403,9 @@ public class FlowMyFacesCDIRequestTestCase extends AbstractMyFacesCDIRequestTest
         processLifecycleExecute();
         
         currentFlow = facesContext.getApplication().getFlowHandler().getCurrentFlow(facesContext);
-        Assert.assertNotNull(currentFlow);
+        Assertions.assertNotNull(currentFlow);
         // We are still on flowA, just returned to base
-        Assert.assertEquals("flowA", currentFlow.getId());
+        Assertions.assertEquals("flowA", currentFlow.getId());
         
         renderResponse();
         
@@ -415,11 +416,11 @@ public class FlowMyFacesCDIRequestTestCase extends AbstractMyFacesCDIRequestTest
         processLifecycleExecute();
         
         facesContext.getApplication().getFlowHandler().getCurrentFlowScope().put("flowB","valueB_1");
-        Assert.assertEquals("/flowB/flowB.xhtml", facesContext.getViewRoot().getViewId());
+        Assertions.assertEquals("/flowB/flowB.xhtml", facesContext.getViewRoot().getViewId());
         
         currentFlow = facesContext.getApplication().getFlowHandler().getCurrentFlow(facesContext);
-        Assert.assertNotNull(currentFlow);
-        Assert.assertEquals(currentFlow.getId(), "flowB");
+        Assertions.assertNotNull(currentFlow);
+        Assertions.assertEquals(currentFlow.getId(), "flowB");
         
         renderResponse();
         
@@ -430,15 +431,15 @@ public class FlowMyFacesCDIRequestTestCase extends AbstractMyFacesCDIRequestTest
         processLifecycleExecute();
         
         currentFlow = facesContext.getApplication().getFlowHandler().getCurrentFlow(facesContext);
-        Assert.assertNotNull(currentFlow);
-        Assert.assertEquals("flowA", currentFlow.getId());
-        Assert.assertFalse(facesContext.getApplication().getFlowHandler().getCurrentFlowScope().containsKey("flowB"));
+        Assertions.assertNotNull(currentFlow);
+        Assertions.assertEquals("flowA", currentFlow.getId());
+        Assertions.assertFalse(facesContext.getApplication().getFlowHandler().getCurrentFlowScope().containsKey("flowB"));
         facesContext.getApplication().getFlowHandler().getCurrentFlowScope().put("flowA","valueA_2");
         
         renderResponse();
         
         //Check current view is the begin of flow2
-        Assert.assertEquals("/flowA/flowA.xhtml", facesContext.getViewRoot().getViewId());
+        Assertions.assertEquals("/flowA/flowA.xhtml", facesContext.getViewRoot().getViewId());
 
         // Call flow B through flow call
         UICommand button5 = (UICommand) facesContext.getViewRoot().findComponent("mainForm:call_flow_B");
@@ -447,15 +448,15 @@ public class FlowMyFacesCDIRequestTestCase extends AbstractMyFacesCDIRequestTest
         processLifecycleExecute();
         
         currentFlow = facesContext.getApplication().getFlowHandler().getCurrentFlow(facesContext);
-        Assert.assertNotNull(currentFlow);
-        Assert.assertEquals("flowB", currentFlow.getId());
-        Assert.assertFalse(facesContext.getApplication().getFlowHandler().getCurrentFlowScope().containsKey("flowA"));
+        Assertions.assertNotNull(currentFlow);
+        Assertions.assertEquals("flowB", currentFlow.getId());
+        Assertions.assertFalse(facesContext.getApplication().getFlowHandler().getCurrentFlowScope().containsKey("flowA"));
         facesContext.getApplication().getFlowHandler().getCurrentFlowScope().put("flowB","valueB_2");
         
         renderResponse();
         
         //Check current view is the begin of flow2
-        Assert.assertEquals("/flowB/flowB.xhtml", facesContext.getViewRoot().getViewId());
+        Assertions.assertEquals("/flowB/flowB.xhtml", facesContext.getViewRoot().getViewId());
         
         UICommand button6 = (UICommand) facesContext.getViewRoot().findComponent("mainForm:end_flow");
         client.submit(button6);
@@ -463,9 +464,9 @@ public class FlowMyFacesCDIRequestTestCase extends AbstractMyFacesCDIRequestTest
         processLifecycleExecute();
         
         currentFlow = facesContext.getApplication().getFlowHandler().getCurrentFlow(facesContext);
-        Assert.assertNotNull(currentFlow);
-        Assert.assertEquals("flowA", currentFlow.getId());
-        Assert.assertEquals("valueA_2", facesContext.getApplication().getFlowHandler().getCurrentFlowScope().get("flowA"));
+        Assertions.assertNotNull(currentFlow);
+        Assertions.assertEquals("flowA", currentFlow.getId());
+        Assertions.assertEquals("valueA_2", facesContext.getApplication().getFlowHandler().getCurrentFlowScope().get("flowA"));
         
         renderResponse();
         
@@ -475,9 +476,9 @@ public class FlowMyFacesCDIRequestTestCase extends AbstractMyFacesCDIRequestTest
         processLifecycleExecute();
         
         currentFlow = facesContext.getApplication().getFlowHandler().getCurrentFlow(facesContext);
-        Assert.assertNotNull(currentFlow);
-        Assert.assertEquals("flowB", currentFlow.getId());
-        Assert.assertEquals("valueB_1", facesContext.getApplication().getFlowHandler().getCurrentFlowScope().get("flowB"));
+        Assertions.assertNotNull(currentFlow);
+        Assertions.assertEquals("flowB", currentFlow.getId());
+        Assertions.assertEquals("valueB_1", facesContext.getApplication().getFlowHandler().getCurrentFlowScope().get("flowB"));
 
         renderResponse();
         
@@ -487,9 +488,9 @@ public class FlowMyFacesCDIRequestTestCase extends AbstractMyFacesCDIRequestTest
         processLifecycleExecute();
         
         currentFlow = facesContext.getApplication().getFlowHandler().getCurrentFlow(facesContext);
-        Assert.assertNotNull(currentFlow);
-        Assert.assertEquals("flowA", currentFlow.getId());
-        Assert.assertEquals("valueA_1", facesContext.getApplication().getFlowHandler().getCurrentFlowScope().get("flowA"));
+        Assertions.assertNotNull(currentFlow);
+        Assertions.assertEquals("flowA", currentFlow.getId());
+        Assertions.assertEquals("valueA_1", facesContext.getApplication().getFlowHandler().getCurrentFlowScope().get("flowA"));
         
         renderResponse();
         
